
set more off

global fontface = "fontface('Times-Roman')"

est clear
drop _all
use /tmp/bsample_`1'.dta

summ hhidpn
local max_hhidpn = r(max)
sort hhidpn wave
by hhidpn wave: replace hhidpn = (`max_hhidpn' + 1) * (_n - 1) + hhidpn 

 local var = "rnumdis"
 local util = "rwhappy"
 local sample = 0

keep if sample0 == 1

summ rnumdis, det
summ rwhappy, det

replace log_inc_perm = log(inc_perm / 1000)

summ log_inc_perm, det
local mean = r(mean)
local median = r(p50)

/**
 ** Within-individual decline going from <=2 diseases to >2 diseases
 **  (DiD)
 **/
summ rwhappy if log_inc_perm >= `median' & rnumdis < 2
summ rwhappy if log_inc_perm < `median' & rnumdis  < 2

capture drop S
gen S = (rnumdis > 2)

/**
 ** Keep only individuals which appear both below and above median
 **/
sort hhidpn wave
by hhidpn: keep if S[1] == 0 & S[_N] == 1

** 
* This code was use to explore other figures
**
*foreach q of numlist 2 3 4 5 6 7 8 9 10 20 {

capture drop myn
sort hhidpn wave
by hhidpn: gen myn = _n

count
count if myn == 1

foreach q of numlist 3 {

 di "q: `q'..."
 preserve
xtile y = log_inc_perm, nquantiles(`q')
gen rwhappy0 = rwhappy if S == 0
gen rwhappy1 = rwhappy if S == 1
gen rwhappy0_sd = rwhappy if S == 0
gen rwhappy1_sd = rwhappy if S == 1
gen rwhappy0_N = 1 if S == 0
gen rwhappy1_N = 1 if S == 1

di "counting..."
count
count if S == 0
count if S == 1
bys y: count
bys y S: count

/**
reg rwhappy if S == 0 & y == 1
reg rwhappy if S == 1 & y == 1
reg rwhappy if S == 0 & y == 2
reg rwhappy if S == 1 & y == 2
 **/
collapse (mean) rwhappy0-rwhappy1 (sd) rwhappy0_sd-rwhappy1_sd (sum) rwhappy0_N-rwhappy1_N, by(y)
sort y


gen rwhappy0_se = rwhappy0_sd / sqrt(rwhappy0_N)
gen rwhappy1_se = rwhappy1_sd / sqrt(rwhappy1_N)

gen rwhappy0_upper = rwhappy0 + 1.96 * rwhappy0_se
gen rwhappy0_lower = rwhappy0 - 1.96 * rwhappy0_se

gen rwhappy1_upper = rwhappy1 + 1.96 * rwhappy1_se
gen rwhappy1_lower = rwhappy1 - 1.96 * rwhappy1_se

drop *_sd *_N
gen diff = rwhappy1 - rwhappy0
list

** Do this for "b" figures...
*replace y = y / `q' - 1/(2*`q') if rwhappy1 < .

*set obs 200
*replace y = (_n - 0.5) / _N if missing(y)

gen y3 = y*y*y
reg rwhappy1 y y3
predict xb1, xb
reg rwhappy0 y y3
predict xb0, xb


replace rwhappy0 = 100 * rwhappy0
replace rwhappy1 = 100 * rwhappy1

replace rwhappy0_upper = 100 * rwhappy0_upper
replace rwhappy0_lower = 100 * rwhappy0_lower
replace rwhappy1_upper = 100 * rwhappy1_upper
replace rwhappy1_lower = 100 * rwhappy1_lower


if (`q' == 3) {

  label define cat 1 "Lowest tercile" 2 "Middle tercile" 3 "Highest tercile"
  label values y cat

/**
 ** generate plot without "caps"
  twoway ///
 (scatter rwhappy0 y, msize(medlarge) msymbol(T) mcolor(gs4)) /// 
 (scatter rwhappy1 y,  msize(medlarge) mcolor(gs10) ), /// 
    scheme(s2mono) graphregion(fcolor(white)) ///
    legend( pos(5) ring(0) cols(2)) legend(label(1 "Good Health")) legend(label(2 "Poor Health")) ///
    xtitle("Permanent Income") ytitle("Percent Happy") xscale(r(0.5 3.5)) yscale(r(79.6 92.4)) xlabel(1 2 3, valuelabel) ylabel(80(2)92)
 graph export ./output/figure1_`q'a.eps, $fontface replace
 !epstopdf ./output/figure1_`q'a.eps
 !rm ./output/figure1_`q'a.eps
 **/

  ** generate plot  
  twoway ///
 (scatter rwhappy0 y, msize(medlarge) msymbol(T) mcolor(gs4)) /// 
 (scatter rwhappy1 y,  msize(medlarge) mcolor(gs10) ) /// 
 (rcap rwhappy0_lower rwhappy0_upper y, lcolor(gs4)) /// 
 (rcap rwhappy1_lower rwhappy1_upper y, lcolor(gs10) ), /// 
    scheme(s2mono) graphregion(fcolor(white)) ///
    legend( pos(5) ring(0) cols(2) order(1 2)) legend(label(1 "Good Health")) legend(label(2 "Poor Health")) ///
    xtitle("Permanent Income") ytitle("Percent Happy") xscale(r(0.5 3.5)) yscale(r(79.6 92.4)) xlabel(1 2 3, valuelabel) ylabel(80(2)92)
 graph export ./output/figure1_`q'b.eps, $fontface replace
 !epstopdf ./output/figure1_`q'b.eps
 !rm ./output/figure1_`q'b.eps

 list
}

if (`q' == 2) {

  label define cat 1 "Below Median" 2 "Above Median"
  label values y cat

  twoway ///
 (scatter rwhappy0 y, msize(medium) msymbol(T)) /// 
 (scatter rwhappy1 y,  msize(medium) mcolor(gs10) ), /// 
    scheme(s2mono) graphregion(fcolor(white)) ///
    legend(cols(2)) legend(label(1 "Good Health")) legend(label(2 "Poor Health")) ///
    title("Figure 3") xtitle("Permanent Income") ytitle("Percent Happy") xscale(r(0.5 2.5)) yscale(r(79.6 92.4)) xlabel(1 2, valuelabel) ylabel(80(2)92)
 graph export ./output/figure1_`q'a.eps, $fontface replace
 !epstopdf ./output/figure1_`q'a.eps
 !rm ./output/figure1_`q'a.eps
 **!rm jeea/figure`q'a.eps

}

/**
  ** generate plot
  twoway ///
 (scatter rwhappy0 y, msize(medium) msymbol(T)) /// 
 (scatter rwhappy1 y,  msize(medium) mcolor(gs10) ), /// 
    scheme(s2mono) graphregion(fcolor(white)) ///
    legend(off) title("Figure X") xtitle("Permanent Income (Quantile)") ytitle("Percent Happy") xlabel(0(0.2)1) 

 graph export jeea/figure`q'b.eps, $fontface replace
 !epstopdf jeea/figure`q'b.eps
 **!rm jeea/figure`q'b.eps
 **/

 restore
}

exit

