

clear
set mem 800m
set more off
set linesize 120
set maxvar 10000

clear 
use all_years_hrs
gen long hhidpn = 1000*real(HHID) + real(PN)
gen wave = 1 if year == 1992
replace wave = 2 if year == 1993 | year == 1994
replace wave = 3 if year == 1996 | year == 1995
replace wave = 4 if year == 1998
replace wave = 5 if year == 2000
replace wave = 6 if year == 2002
replace wave = 7 if year == 2004
replace wave = 8 if year == 2006

rename seatbelt seat_belt

rename medication_hbp  med_hibpe
rename medication_diab med_diabe
rename medication_lung med_lunge
rename medication_ht_angina med_hearte_angina
rename medication_ht_chf    med_hearte_chf
rename medication_stroke    med_stroke
rename medication_arth      med_arthre
rename medication_ht_htmed  med_hearte_htm
rename medication_ht_attack med_hearte_attack

sort hhidpn wave
save /tmp/hrs_full.dta, replace



/**
 This is the "panel" data set that is created by rand.do and it is
based on the RAND data file.  
**/
clear
use rand_panel


**
* drop if died or did not respond
*
assert riwstat  < .
drop if riwstat > 1 | riwstat == 0


/**
 BRING IN HRS DATA(!)
 **/ 

sort hhidpn wave
merge hhidpn wave using /tmp/hrs_full.dta

bys wave: tab _merge
** check wave 2(!) 
drop if _merge == 2
capture drop _merge
bys wave: tab seat_belt rseatBelts, missing
drop rseatBelts
rename seat_belt rseatBelts

replace med_hibpe = 0 if rhibpe < . & missing(med_hibpe)
replace med_diabe = 0 if rdiabe < . & missing(med_diabe)
replace med_lunge = 0 if rlunge < . & missing(med_lunge)
replace med_hearte_angina = 0 if rhearte < . & missing(med_hearte_angina)
replace med_hearte_chf    = 0 if rhearte < . & missing(med_hearte_chf)
replace med_hearte_htm    = 0 if rhearte < . & missing(med_hearte_htm)
replace med_hearte_attack = 0 if rhearte < . & missing(med_hearte_attack)
replace med_arthre  = 0 if rarthre < . & missing(med_arthre)
replace med_stroke  = 0 if rstroke < . & missing(med_stroke)

replace med_hibpe = 0 if rhibpe == 0 & med_hibpe == 1
replace med_diabe = 0 if rdiabe == 0 & med_diabe == 1
replace med_lunge = 0 if rlunge == 0 & med_lunge == 1
replace med_hearte_angina = 0 if rhearte == 0 & med_hearte_angina == 1
replace med_hearte_chf    = 0 if rhearte == 0 & med_hearte_chf == 1
replace med_hearte_htm    = 0 if rhearte == 0 & med_hearte_htm == 1
replace med_hearte_attack = 0 if rhearte == 0 & med_hearte_attack == 1
replace med_arthre  = 0 if rarthre == 0 & med_arthre == 1
replace med_stroke  = 0 if rstroke == 0 & med_stroke == 1

gen med_hearte = med_hearte_angina + med_hearte_chf + med_hearte_htm + med_hearte_attack
replace med_hearte = 1 if med_hearte > 0 & med_hearte < .

drop med_hearte_angina med_hearte_chf med_hearte_htm med_hearte_attack

gen med_tot = ///
 med_hibpe + med_diabe + med_lunge + ///
 med_hearte +  med_arthre + med_stroke

bys wave: tab rhibpe med_hibpe, missing
bys wave: tab rdiabe med_diabe, missing
bys wave: tab rlunge med_lunge, missing
bys wave: tab rlunge med_hearte, missing
bys wave: tab rarthre med_arthre, missing
bys wave: tab rstroke med_stroke, missing

desc st_* diab_* lung_*
foreach var of varlist st_* {
  replace `var' = 0 if rstroke < . & missing(`var')
  replace `var' = 0 if rstroke == 0 & `var' == 1
}
foreach var of varlist diab_* {
  replace `var' = 0 if rdiabe < . & missing(`var')
  replace `var' = 0 if rdiabe == 0 & `var' == 1
}
foreach var of varlist lung_* {
  replace `var' = 0 if rlunge < . & missing(`var')
  replace `var' = 0 if rlunge == 0 & `var' == 1
}

** egen diab_sev   = rowtotal(diab_*)
gen diab_sev = diab_hosp + diab_insu
gen diab_sev2 = 0
replace diab_sev2 = 1 if diab_sev > 0 & diab_sev < .

egen stroke_sev = rowtotal(st_*)
gen stroke_sev2 = 0
replace stroke_sev2 = 1 if stroke_sev > 0 & stroke_sev < .


**
bys wave: tab pain_freq

replace pain_severe = 0 if pain_freq == 0
replace pain_severe = 1 if pain_freq == 1 & missing(pain_severe)
rename pain_severe pain_s
rename pain_freq   pain_f




/**
 This file modifies the variables in rand_panel and saves the "final" data set
 used by the basic regressions in the following ways:

 - VARIABLE RESTRICTIONS
 - VARIABLE RELABELINGS
 - VARIABLE RESCALINGS
**/






** within-person numbering
bys hhidpn: gen myn = _n



** FIX CESD SCALE:
** RESCALE SO THAT [0-8] IS "NUMBER OF QUESTIONS ANSWERED 'HAPPILY'"
**  (i.e. *LOWER* values mean that you are *MORE* depressed)
replace rcesd = rwhappy + renlife + (1-rfsad) + (1-rflone) + ///
 (1-rgoing) + (1-rsleepr) + (1-reffort) + (1-rdepres)
replace scesd = 8 - scesd

**
* smith et al paper uses 
*  4 CESD questions (happy, enjoy life, sad, lonely)
gen rcesd4 = rwhappy + renlife + (1 - rfsad) + (1 - rflone)
gen scesd4 = swhappy + senlife + (1 - sfsad) + (1 - sflone)





** MEHTA SCALE
gen not_depressed = .
replace not_depressed = 1 if (rcesd >  5 & rcesd < .)
replace not_depressed = 0 if (rcesd <= 5)
rename not_depressed rnotdep

** DO NOT INCLUDE BACK PAIN FOR "ANY" FOR RIGHT NOW


gen ranyDisease = (rhibpe | rdiabe | rcancre | rlunge | rhearte | rstroke  | rarthre)
gen ranyChronic = (rpsyche | rarthre | rdiabe)
gen ranyAcute   = (rcancre | rlunge | rstroke)

gen sanyDisease = (shibpe | sdiabe |  scancre | slunge | shearte | sstroke | sarthre)
gen sanyChronic = (spsyche | sarthre | sdiabe)
gen sanyAcute   = (scancre | slunge  | sstroke)

gen hanyDisease  = (ranyDisease | sanyDisease)

gen rnumdis = rhibpe + rdiabe + rcancre + rlunge + rhearte + rstroke + rarthre 
gen snumdis = shibpe + sdiabe +  scancre + slunge + shearte + sstroke + sarthre


gen rnumdis6 = rhibpe + rdiabe + rlunge + rhearte + rstroke + rarthre 

gen lng_db_st = rdiabe + rlunge + rstroke
gen lng_db_st_sev = diab_sev2 + lung_oxy + stroke_sev2

gen lung_diab = rdiabe + rlunge
gen lung_diab_sev = diab_sev2 + lung_oxy



**
* disease severity measures
gen med_frac = med_tot / rnumdis

gen rnd_wpsy = rnumdis + rpsyche
gen snd_wpsy = snumdis + spsyche

local adls = " walkra dressa batha eata beda toilta"
foreach adl of local adls {
 rename r`adl' r_adl_`adl'
 rename s`adl' s_adl_`adl'
}
capture drop *_nonmiss
egen r_nonmiss = rownonmiss(r_adl_*)
egen s_nonmiss = rownonmiss(s_adl_*)
egen radl_tot = rowtotal(r_adl_*) if r_nonmiss > 0
egen sadl_tot = rowtotal(s_adl_*) if s_nonmiss > 0
egen hadl_tot = rowtotal(r_adl_* s_adl_*) if r_nonmiss > 0 | s_nonmiss > 0


local iadls = " mapa phonea moneya medsa shopa mealsa"
foreach iadl of local iadls {
 rename r`iadl' r_iadl_`iadl'
 rename s`iadl' s_iadl_`iadl'
}
capture drop *_nonmiss
egen r_nonmiss = rownonmiss(r_iadl_*)
egen s_nonmiss = rownonmiss(s_iadl_*)
egen riadl_tot = rowtotal(r_iadl_*) if r_nonmiss > 0
egen siadl_tot = rowtotal(s_iadl_*) if s_nonmiss > 0
egen hiadl_tot = rowtotal(r_iadl_* s_iadl_*) if r_nonmiss > 0 | s_nonmiss > 0

local ofls  = " walksa walk1a sita chaira climsa clim1a stoopa dimea armsa pusha"
foreach ofl of local ofls {
 rename r`ofl' r_ofl_`ofl'
 rename s`ofl' s_ofl_`ofl'
}
capture drop *_nonmiss
egen r_nonmiss = rownonmiss(r_ofl_*)
egen s_nonmiss = rownonmiss(s_ofl_*)
egen rofl_tot = rowtotal(r_ofl_*) if r_nonmiss > 0
egen sofl_tot = rowtotal(s_ofl_*) if s_nonmiss > 0
egen hofl_tot = rowtotal(r_ofl_* s_ofl_*) if r_nonmiss > 0 | s_nonmiss > 0

sum *_tot








rename sshlt s_sh
rename rshlt r_sh
rename shlthlm s_sh_limwk
rename rhlthlm r_sh_limwk
egen h_sh = rowtotal(s_sh r_sh) if s_sh < . | r_sh < .
egen h_sh_limwk = rowtotal(s_sh_limwk r_sh_limwk) if s_sh_limwk < . | r_sh_limwk < .
gen r_sh_u = 5 - r_sh
gen s_sh_u = 5 - s_sh


replace ranyDisease = . if rnumdis >= .

** note: use rnumdis, not snumdis
**       we want this to be zero otherwise
replace sanyDisease = . if rnumdis >= .
replace sanyDisease = 0 if rnumdis < . & snumdis >= .

replace snumdis = . if rnumdis >= .
replace snumdis = 0 if snumdis >= . & rnumdis < .

gen hnumdis = rnumdis
replace hnumdis = (rnumdis + snumdis) if snumdis < .

replace hanyDisease = . if hnumdis >= .

foreach p in  hibpe diabe cancre lunge hearte stroke psyche arthre anyChronic anyAcute {
 ** BUG(!) gen h`p' = (r`p' | s`p')
 gen h`p' = .
 replace h`p' = 0 if r`p' == 0 & s`p' != 1
 replace h`p' = 1 if r`p' == 1 | s`p' == 1

 gen b`p' = .
 replace b`p' = 0 if r`p' == 0 | s`p' != 1
 replace b`p' = 1 if r`p' == 1 & s`p' != 0
}




**
* dor, sudano, baker measure
**gen rh_idx = r_sh + rofl_tot + riadl_tot + radl_tot + pain_s
gen rh_idx = rofl_tot + riadl_tot + radl_tot + pain_s


/**
initialize utility weights
 **/
matrix utility_weights = J(1,8,0)
matrix utility_weights[1,1] = .109
matrix utility_weights[1,2] = .045
matrix utility_weights[1,3] = .224
matrix utility_weights[1,4] = .346
matrix utility_weights[1,5] = .293
matrix utility_weights[1,6] = .171

** 0 out psyche
matrix utility_weights[1,7] = 0.00

matrix utility_weights[1,8] = .199


gen rnumDisWgt = ///
  utility_weights[1,1] * rhibpe +  utility_weights[1,2] * rdiabe + ///
  utility_weights[1,3] * rcancre + utility_weights[1,4] * rlunge + ///
  utility_weights[1,5] * rhearte + utility_weights[1,6] * rstroke + ///
  utility_weights[1,7] * rpsyche + utility_weights[1,8] * rarthre

gen snumDisWgt = ///
  utility_weights[1,1] * shibpe +  utility_weights[1,2] * sdiabe + ///
  utility_weights[1,3] * scancre + utility_weights[1,4] * slunge + ///
  utility_weights[1,5] * shearte + utility_weights[1,6] * sstroke + ///
  utility_weights[1,7] * spsyche + utility_weights[1,8] * sarthre

replace snumDisWgt = . if rnumDisWgt >= .
replace snumDisWgt = 0 if snumDisWgt >= .


gen hnumDisWgt = rnumDisWgt
replace hnumDisWgt = rnumDisWgt + snumDisWgt if snumDisWgt < .



** FIX SEATBELTS
/**
 E90.
                  When you ride in a car, how often do you wear your seatbelt?
                  Is it all or most of the time, sometimes, rarely, or never?
          ................................................................................
           9447         1. ALL OR MOST
            687         2. SOMETIMES
            260         3. RARELY
            434         4. NEVER
             45         8. DK (don't know); NA (not ascertained)
              9         9. RF (refused)
           8698     Blank. INAP (Inapplicable); [Q1101:A21Y1] IS (LT 65) AND
                           [Q753:CS22Y30] IS (1); partial interview
**/
replace rseatBelts = 0 if rseatBelts > 1 & rseatBelts < .



** AGE (AGE IN YEARS AS MEASURED AT *BEGINNING* OF YEAR)
rename ragey_b rage
rename sagey_b sage





gen rageSquared = rage * rage / 100
gen sageSquared = sage * sage / 100


** ".u" means unmarried/single
tab siwstat if myn == 1, missing

/** 
 CREATE SAMPLE VARIABLES
**/
gen noWaveOne = (wave != 1)
gen noUnder65 = (rage >= 65)

/** 
 IF ALWAYS SINGLE, set to 1
 **/
sort hhidpn
by hhidpn: gen  temp_stat     = (siwstat >= .)
by hhidpn: gen  temp_resp_stat     = (riwstat < .)
by hhidpn: egen sum_temp_stat = sum(temp_stat)
by hhidpn: egen sum_temp_resp_stat = sum(temp_resp_stat)
gen alwaysSingle = (sum_temp_stat == sum_temp_resp_stat)
tab alwaysSingle if myn == 1
drop *_temp_*

gen single = siwstat >= .




/** 
 IF ALWAYS HAVE HEALTH INSURANCE, set to 1
 **/
sort hhidpn

** >=65 ASSUME medicare
*tab rgovmr if rage > 65, missing
replace rgovmr = 1 if rage >= 65

** health insurance variable includes ALL BUT Long-term care insurance!
gen hasHealthInsurance = (rhigov == 1 | rgovmr == 1 | rgovmd == 1 | rgovva == 1 | rcovr == 1 | rcovs == 1 | rhiothp == 1)
replace hasHealthInsurance = . if missing(rhigov) & missing(rcovr) & missing(rcovs) & missing(rhiothp)

tab hasHealthInsurance if rage >  65
tab hasHealthInsurance if rage >= 65

gen sp_hasHealthInsurance = (shigov == 1 | sgovmr == 1 | sgovmd == 1 | sgovva == 1 | scovr == 1 | scovs == 1 | shiothp == 1)
replace sp_hasHealthInsurance = . if missing(shigov) & missing(scovr) & missing(scovs) & missing(shiothp)

** replace hasHealthInsurance = 0 if hasHealthInsurance >= .

by hhidpn: egen sum_temp_hi = sum(hasHealthInsurance) 
by hhidpn: egen sum_temp_resp_hi = count(hasHealthInsurance)
gen alwaysHasInsurance = (sum_temp_hi == sum_temp_resp_hi)
tab alwaysHasInsurance if myn == 1

tab rage rgovmr
tab hasHealthInsurance
tab hasHealthInsurance if rage >= 65
tab alwaysHasInsurance

sort hhidpn wave
by hhidpn: gen hashi_diff = hasHealthInsurance[_n] - hasHealthInsurance[_n - 1]
replace hashi_diff = 0 if hashi_diff != -1
by hhidpn: egen loses_hi = sum(hashi_diff)

gsort hhidpn -hasHealthInsurance wave 
by hhidpn: gen firstHi = wave[1]
gsort hhidpn hasHealthInsurance wave 
by hhidpn: gen lastHi  = wave[_N]
gen diff_lastHi_firstHi = lastHi - firstHi
tab diff_lastHi_firstHi, missing 

assert(loses_hi == 0) if alwaysHasInsurance  == 1



** set missing incomes to 0
**  
** NEW STATA TRICK!
**  since Stata now supports multiple missing values
**  (see here: http://www.stata.com/help.cgi?missing)
**  and the RAND takes advantage of this new support
**  you can't use equals operator to test for missing
**  anymore

** [I think this syntax is confusing and misleading,
**  but oh well]

** spouse incomes
replace sipena = 0 if sipena >= .
replace siearn = 0 if siearn >= .
replace sissdi = 0 if sissdi >= .
replace sisret = 0 if sisret >= .
replace sigxfr = 0 if sigxfr >= .

** repsondent incomes
replace ripena = 0 if ripena >= .
replace riearn = 0 if riearn >= .
replace risret = 0 if risret >= .
replace rissdi = 0 if rissdi >= .
replace rigxfr = 0 if rigxfr >= .

** generate totals
**  need to add HOUSEHOLD capital income and HOUSEHOLD "other income"
gen resp_tot_inc = (ripena + riearn + rissdi + risret + rigxfr)
gen hh_tot_inc   = (ripena + riearn + rissdi + risret + rigxfr + sipena + siearn + sissdi + sisret + sigxfr)


rename hh_tot_inc hh_tot_inc_old
rename ritot hh_tot_inc
replace hh_tot_inc_old = . if hh_tot_inc >= .
summ hh_tot_inc_old hh_tot_inc, det
gen log_a = log(hh_tot_inc_old)
gen log_b = log(hh_tot_inc)
corr log_a log_b
reg log_b log_a

**
* raira  - net value of IRA, Keogh
* ratotf - Sum (HwASTCK, HwACHCK, HwACD, HwABOND, HwAOTHR) - HwDEBT
*   - net value of stocks, mutual funds, and investment trusts
*   - value of checking, savings, money market
*   - value of CD, gov't savings bonds, T-bills
*   - net value of bonds and bond funds
*   - other savings, assets
*   - other debt
**
gen wealth = ratotf + raira
gen wealth_all = ratota

gen hh_tot_inc_w0pct = hh_tot_inc
gen hh_tot_inc_w10pct = 0.10 * wealth + hh_tot_inc if wealth < . & wealth > 0

summ hh_tot_inc, det
replace hh_tot_inc = 0.05 * wealth + hh_tot_inc if wealth < . & wealth > 0
summ hh_tot_inc, det





**
* icap includes IRA's, CD's, mutual fund sales, etc.
**
gen dc_inc = ricap + riothr

gen ss_pen = ripena + sipena + rissdi + sissdi + risret + sisret 

gen ripena2 = ripena
bys hhidpn: egen has_dc = sum(pension_dc == 1)
replace has_dc = 1 if has_dc > 1 & has_dc < .
replace ripena2 = 0 if has_dc == 1

gen ss_pen2 = ripena2 + sipena + rissdi + sissdi + risret + sisret 



** dummies for spouse in labor market and disability status
gen spouse_working  = ssayret != 1 & ssayret != 3 & siearn > 5000 & siearn < .
gen resp_disabled   = rissdi > 0 & rissdi < .
gen spouse_disabled = sissdi > 0 & sissdi < .


/**
 IMPOSE RETIREMENT RESTRICTIONS:

 We code retired as satisfying ALL of the following conditions:

 (1) must have less than $5000 of *OWN* wages/salary earnings
 (2) must be self-reported retired or answer "not applicable" to
     retirement question
 (3) must have "well-behaved" retirement status

 ALL SUBSEQUENT RESULTS WILL USE THIS "RESTRICTED" SAMPLE
 OF RETIRED PERSONS!!
 **/


 ** BEFORE RETIREMENT RESTRICTION
tab wave

 ** look at retirement tabulation
tab rsayret, missing



*
* create isretired and spouse_retired
* spouse_retired is 0 if no spouse
*
gen ishomemaker_temp = (rsayret == 3 & wave >= 5)
bys hhidpn: egen ishomemaker = sum(ishomemaker_temp)
replace ishomemaker = (ishomemaker > 0)

foreach var of varlist rsayret ssayret {
 local isretired = "isretired"
 if ("`var'" == "ssayret") {
  local isretired = "spouse_retired"
 }

 gen `isretired' = .
 replace `isretired' = 1 if  (`var' == 1 | `var' == 3) 
 replace `isretired' = 0 if  (`var' != 1 & `var' != 3 & `var' < .) | riearn > 5000
 tab wave `isretired', missing
 tab wave `isretired' if rage > 65, missing

 **
 * we will ASSUME you are retired if you are missing but age is >65, retirement status is missing

 gen `isretired'_old = `isretired'
 sort hhidpn wave
 replace `isretired'_old = 1 if (`var' == .q | `var' == .a) & `isretired'_old[_n - 1] == 1
 sort hhidpn wave
 replace `isretired'_old = 1 if (`var' == .q | `var' == .a) & `isretired'_old[_n + 1] == 1

 sort hhidpn wave
 by hhidpn: replace `isretired' = `isretired'[_n-1] if (`var' == .q | `var' == .a) & (_n > 1) & `isretired'[_n-1] < .
 sort hhidpn wave
 by hhidpn: replace `isretired' = `isretired'[_n+1] if (`var' == .q | `var' == .a) & (_n > 1) & `isretired'[_n+1] < .
 sort hhidpn wave
 by hhidpn: replace `isretired' = `isretired'[_n+1] if (`var' == .q | `var' == .a) & (_n == 1)

/**
 if ("`isretired'" == "isretired") {
  replace `isretired' = (rlbrf == 5 | rlbrf == 7 | rlbrf == .a) if (`var' == .q | `var' == .a)
 }
 else { 
  if ("`isretired'" == "spouse_retired") {
   replace `isretired' = (slbrf == 5 | slbrf == 7 | slbrf == .a) if (`var' == .q | `var' == .a)
  }
  else {
   die ("INVARIANT FAILED!")
  }
 }
**/

 tab `isretired' `isretired'_old, missing
}


** 5 - retired
** 7 - nilf
** .A - presumed retired
gen isretired_lbrf = (rlbrf == 5 | rlbrf == 7 | rlbrf == .a)



**tab rgovmr if isretired == 1 & rage >= 65, missing
**kaboom






/**
        +----------------------------------------------
        |   hhidpn   wave   hasHea~e   rage   isretired
        |----------------------------------------------
 58606. | 78672020      1          1     59          1 
 58607. | 78672020      2          1     61          1 
 58608. | 78672020      3          1     63          1 
 58609. | 78672020      4          1     65          1 
 58610. | 78672020      5          1     67          . 
        |----------------------------------------------
 58611. | 78672020      6          1     69          1 
        +----------------------------------------------
**/
/**
sort hhidpn wave
by hhidpn: replace isretired = 1 if (isretired >= .) & isretired[_n-2] == 1 & isretired[_n-1] == 1 & isretired[_n+1] == 1
sort hhidpn wave
by hhidpn: replace isretired = 1 if (isretired >= .) & isretired[_n-1] == 1 & isretired[_n+1] == 1 & isretired[_n+2] == 1
sort hhidpn wave
by hhidpn: replace isretired = 1 if (isretired >= .) & isretired[_n-3] == 1 & isretired[_n-2] == 1 & isretired[_n-1] == 1
 **/
*sort hhidpn wave
*by hhidpn: replace isretired = 1 if isretired >= . & isretired[_n-1] == 1 & _n == _N
*sort hhidpn wave
*by hhidpn: replace isretired = 1 if isretired >= . & isretired[_n+1] == 1 & _n == 1




replace spouse_retired = 0 if single == 1




**
** hhidpn is derived from household number and person number
**  (IT IS OUR PRIMARY PANEL ID VARIABLE)
**
*sort hhidpn wave
*by hhidpn: replace isretired = isretired[_n + 1] if isretired == . & isretired[_n + 1] < .
sort hhidpn wave
by hhidpn: gen retired_diff = isretired[_n] - isretired[_n - 1]

tab retired_diff, missing
tab wave isretired, missing
tab wave isretired if rage > 65, missing

** 
** -1 means transitioning from retired to non-retired
**  0 means stays in same state
** +1 means transitioning from non-retired to retired
**
** WE WANT TO MAKE SURE RETIREMENT IS ABSORBING
tab retired_diff, missing

** FOR NOW, DROP ALL PERSONS WITH -1 TRANSITION
gen isNegative1 = (retired_diff == -1)
bys hhidpn: gen hasNegative1 = sum(isNegative1)
tab hasNegative1, missing
** drop if hasNegative1 > 0
count if myn == 1
count if myn == 1 & hasNegative1 == 1 
**replace isretired = 0 if hasNegative1 > 0


** keep if isretired == 1

 ** AFTER RETIREMENT RESTRICTION


********************
** CESD RESTRICTIONS
********************

** UNWEIGHTED HAPPINES TABULATION, by wave
bys wave: tab rcesd, missing

/** drop missing CESD index values

  NOTE: many of these are because of PROXY responses
  TODO: if you are proxy one year and then come back in
        can we still use you?  we are currently allowing
        people to jump out and back in as long as they are
        retired before and after the "jump"
**/ 
drop if rcesd >= .




********************
** AGE RESTRICTIONS
********************
/**
 DROP MISSING AGES VALUES (FOR NOW)
**/
drop if rage >= .




********************
** ERZO INCOME VARIABLES
********************

**  create PERMANENT and CURRENT household income variables
**  and CURRENT respondent earnings variables

**  log_inc_perm - log of average household income (i.e. permanent income for household)
**  log_inc_curr - log of current household income (in wave t)
**  log_inc_riearn - log of current repsondent earnings (in wave t)

count
count if hh_tot_inc >= .
summ hh_tot_inc


**
* create household size variable
gen hh_size = rhhres
sort hhidpn hh_size
by hhidpn: gen hh_size_diff = hh_size[_N] - hh_size[1]
tab hh_size_diff if myn == 1
sort hhidpn wave
by hhidpn: replace hh_size = hh_size[1]
tab hh_size, missing

gen oecd_adj_full = 1.0 if hh_size == 1
replace oecd_adj_full = 1.0 + (hh_size - 1) * 0.7 if hh_size > 1 & hh_size < .
count if oecd_adj_full < .
tab hh_size oecd_adj_full

**
* NOTE: we are ASSUMING oecd adjustment of 1.0 for ALL single people
gen oecd_adj = 1.0 if hh_size == 1 | (single == 1 & hh_size > 1 & hh_size < .)
replace oecd_adj = 1.7 if hh_size > 1 & hh_size < . & single == 0
count if oecd_adj < .
tab hh_size oecd_adj

gen per_cap_full = hh_size

gen per_cap_partial =     1.0 if hh_size == 1 |  (single == 1 & hh_size > 1 & hh_size < .)
replace per_cap_partial = 2.0 if hh_size > 1 & hh_size < . & single == 0

gen sqrt_adj = 1.0 if hh_size == 1 | (single == 1 & hh_size > 1 & hh_size < .)
replace sqrt_adj = sqrt(2) if hh_size > 1 & hh_size < . & single == 0


**
* reset hh_size to CURRENT household size for use as "X" in regressions
replace hh_size = rhhres



di "************"
di "doing CURRENT (TEMPORARY) income ..."
di "************"
gen inc_curr = hh_tot_inc / oecd_adj
gen wealth_curr = wealth  / oecd_adj
gen wealth_all_curr = wealth_all  / oecd_adj
gen inc_w0pct_curr = hh_tot_inc_w0pct / oecd_adj
gen inc_w10pct_curr = hh_tot_inc_w10pct / oecd_adj

gen log_inc_curr   = log(inc_curr)
gen dummy_inc_curr = 0

di "************"
di "doing PERMANENT income ..."
di "************"
local incs = "inc wealth wealth_all inc_w0pct inc_w10pct"
foreach inc of local incs {
 bys hhidpn: egen `inc'_perm = mean(`inc'_curr)

 count
 count if `inc'_perm >= .
 summ `inc'_perm, detail
 summ `inc'_perm if myn == 1, detail 

 gen dummy_`inc'_perm = 0

 gen log_`inc'_perm   = .
 replace log_`inc'_perm = log(`inc'_perm) if dummy_`inc'_perm == 0

 di "************"
 di "`inc' income distribution ..."
 di "************"
 summ log_`inc'_perm, detail
}

summ wealth_perm wealth_all_perm, det

replace dc_inc = dc_inc / oecd_adj
bys hhidpn: egen dc_inc_perm = mean(dc_inc)
gen log_dc_inc_perm = log(dc_inc_perm)

**
* frac wealth DC
gen frac_dc = dc_inc_perm / inc_perm
summ frac_dc, det

replace ss_pen = ss_pen / oecd_adj
replace ss_pen2 = ss_pen2 / oecd_adj

bys hhidpn: egen ss_pen_perm = mean(ss_pen)
bys hhidpn: egen ss_pen_perm2 = mean(ss_pen2)

gen frac_ss_pen = ss_pen_perm / inc_perm
gen frac_ss_pen2 = ss_pen_perm2 / inc_perm
summ frac_ss_pen if rage >= 50 & isretired == 1 , det
summ frac_ss_pen if rage >= 65 , det




** what fraction have permanent income below 5000
**  TODO: *why* is their permanent income so low?
tab dummy_inc_perm

** age distribution
summ rage, detail

/** LIST youngest members of sample
     perhaps the young retired folk are all disabled?

    age
    disability status (respondent then spouse)
    log permanet income
    retirement status (respondent then spouse; 1 = retired, 3 = N/A, 0 = still working)
    spouse working dummy
 **/
sort rage hhidpn
list rage *disabled log_inc_perm log_inc_curr rsayret ssayret spouse_working in 1/2000 if myn == 1


summ log_inc_perm, det

tab rcholst isfemale
tab rflusht isfemale
tab rbreast isfemale
tab rmammog isfemale
tab rpapsm isfemale
tab rprost isfemale

** drop when gender does not match test
drop if isfemale == 1 & rprost < .
drop if isfemale == 0 & rbreast < .
drop if isfemale == 0 & rmammog < .
drop if isfemale == 0 & rpapsm < .


summ rage, det

** eliminate all elderly couples with one member <50
** drop if rage < 50
** drop if sage < 50

/**
                            rage
-------------------------------------------------------------
      Percentiles      Smallest
 1%           48             25
 5%           54             25
10%           57             25       Obs               46733
25%           62             26       Sum of Wgt.       46733

50%           70                      Mean           69.77964
                        Largest       Std. Dev.      10.09299
75%           77            102
90%           83            104       Variance       101.8685
95%           86            105       Skewness       .0044319
99%           92            109       Kurtosis       2.717202
**/



***
* fraction of gender-relevant preventive actions taken
***
gen     rfracPrev = .
replace rfracPrev =  ((rcholst == 1 & rcholst < .) + (rflusht == 1 & rflusht < .) + (rbreast == 1 & rbreast < .) + (rmammog == 1 & rmammog < .) + (rpapsm == 1 & rpapsm < .)) / 5 if isfemale == 1
replace rfracPrev = . if ( ((rcholst >= .) + (rflusht >= .) + (rbreast >= .) + (rmammog >= .) + (rpapsm >= .)) > 0) & isfemale == 1
replace rfracPrev = ((rcholst == 1 & rcholst < .) + (rflusht == 1 & rflusht < .) + (rprost == 1 & rprost < .)) / 3 if isfemale == 0
replace rfracPrev = . if ( ((rcholst >= .) + (rflusht >= .) + (rprost >= .)) > 0) & isfemale == 0

tab rfracPrev if isfemale == 1
tab rfracPrev if isfemale == 0

gen     rfracPrevExt = .
replace rfracPrevExt =  ((rseatBelts == 1 & rseatBelts < .) + (rcholst == 1 & rcholst < .) + (rflusht == 1 & rflusht < .) + (rbreast == 1 & rbreast < .) + (rmammog == 1 & rmammog < .) + (rpapsm == 1 & rpapsm < .)) / 6 if isfemale == 1
replace rfracPrevExt = . if ( ( (rseatBelts >= .) + (rcholst >= .) + (rflusht >= .) + (rbreast >= .) + (rmammog >= .) + (rpapsm >= .)) > 0) & isfemale == 1
replace rfracPrevExt = ((rseatBelts == 1 & rseatBelts < .) + (rcholst == 1 & rcholst < .) + (rflusht == 1 & rflusht < .) + (rprost == 1 & rprost < .)) / 4 if isfemale == 0
replace rfracPrevExt = . if ( ( (rseatBelts >= .) + (rcholst >= .) + (rflusht >= .) + (rprost >= .)) > 0) & isfemale == 0

tab rfracPrev if isfemale == 1
tab rfracPrev if isfemale == 0
tab rseatBelts

save rand_panel_restricted, replace


