
/**
 **

Code to create data set and data tables for 
  "What good is wealth without health?"

NOTES: 

- This code will only run on UNIX/Linux!  It will not run on windows
because it saves temporary files to /tmp/.

- The following three files will re-generate analysis file from the
raw HRS data (not included).

 do rand
 do prepareSample
 do make_rand_hrs_final noi

 **
 **/



clear
set more off
set mem 1800m

set linesize 130

set seed 12345

set type double, permanently

**
** Make data set from "raw" data sets (RAND HRS, raw HRS, etc.)
**
**do rand
**do prepareSample
**do make_rand_hrs_final noi
**
**

est clear
drop _all
use rand_hrs_final.dta

**
* This code helps for bootstrapped standard errors
**
local bsample = 0
global OUTPUT_DIRECTORY = "./output/"
save /tmp/bsample_`bsample'.dta, replace


**
* Create figure 1
**
*do figure1.do 0


**
* Table 1 - summary statistics
**
do table1_summ_stats `bsample'


**
* Table 2 - main (baseline) results
**
*do table2_baseline `bsample' 0
*do table2_baseline `bsample' 15


**
* Table 3 - alternative samples, fixed alpha {1,3,5}
**
*do table3_fixed_alpha `bsample' 1
*do table3_fixed_alpha `bsample' 3
*do table3_fixed_alpha `bsample' 5


**
* Table 4 - nonparametric table
**
*do table4_nonparam `bsample' 0.10 0.5 1
*do table4_nonparam `bsample' 0.05 0.5 2
*do table4_nonparam `bsample' 0.20 0.5 3
*do table4_nonparam `bsample' 0.10 0.2 4
*do table4_nonparam `bsample' 0.10 1.0 5


**
* Table 5 - nonlinear specifications
**
do table5_fe_probit.do
do table5_nlls_xalpha.do


** 
* Table 6 - consumption results
**
*do table6_cons_trend.do `bsample' 0


** 
* Table 7 - Limit based on fraction of wealth annuitized
*  (all, >50%, >75%)
**
*do table7_annuitized `bsample' 0
*do table7_annuitized `bsample' 20
*do table7_annuitized `bsample' 21


**
* Table 8 - Optimal savings simulation (s*)
*  NOTE: These programs write out a log file containing results
**
*do table8_run.do -0.2 2
*do table8_run.do -0.4 4


**
* Table 9 - Optimal insurance simulation (b*)
*  NOTE: These programs write out a log file containing results
**
*do table9_opt_ins2.do
*do table9_opt_ins4.do



exit




