
set more off

capture program drop post_param
program define post_param, eclass
 ereturn scalar `1' = `2'
end


drop _all
use /tmp/bsample_`1'.dta

summ hhidpn
local max_hhidpn = r(max)
sort hhidpn wave
by hhidpn wave: replace hhidpn = (`max_hhidpn' + 1) * (_n - 1) + hhidpn 


**
* check total diseases versus rnumdis+snumdis
**
assert(rnumdis + snumdis == hnumdis)

sort hhid year
by hhid year: egen numdis_temp = sum(rnumdis)

tab hnumdis numdis_temp, missing
count if hnumdis == numdis_temp

bys single: tab hnumdis, missing
assert hnumdis <= 7 if single == 1

/**
 ** individual diseases ...
 **
 ** rhibpe rdiabe rcancre rlunge rhearte rstroke rarthre 
 ** hhibpe hdiabe hcancre hlunge hhearte hstroke harthre 
 **
 **/

global hlist2 = ""
foreach var of varlist hhibpe hdiabe hcancre hlunge hhearte hstroke harthre {
 gen hsingleX`var'  = (single) * `var'
 gen hmarriedX`var' = (1 - single) * `var'
 global hlist2 = "$hlist2 hmarriedX`var'"
}

global blist  = ""
foreach var of varlist bhibpe bdiabe bcancre blunge bhearte bstroke barthre {
 gen bsingleX`var'  = (single) * `var'
 gen bmarriedX`var' = (1 - single) * `var'
 global blist = "$blist bmarriedX`var'"
}

summ hsingleX* hmarriedX*

local var = "hnumdis"
gen singleX`var'  = single * `var'
gen marriedX`var' = (1 - single) * `var' / 2

global hlist = "hhibpe hdiabe hcancre hlunge hhearte hstroke harthre"



**
* get final sample
keep if rwhappy < . 
keep if log_inc_perm < .
keep if single < .
keep if rage < .
keep if isretired < .
keep if hh_size < .
keep if rnumdis < .


** NOTE: Impose this restriction *before* running...
keep if sample0 == 1

**
* drop nursing homes
**
*sort hhid wave rnhmliv
*by hhid wave: drop if rnhmliv[_N] == 1


**
* drop singles
**
if (`2' == 1) {
 keep if alwaysSingle == 1
}


est clear

/**
 ERZO: Instead of using NUM_DISEASE, 
 use FRAC_DISEASE = (NUM_DISEASE / HIGHEST POSSIBLE NUMBER).  
  i.e. divide by 14 for couples, by 7 for individuals.
This will put the disease measure on the same scale for singles and
couples
 **/
assert(hnumdis == rnumdis) if single == 1

replace hnumdis = hnumdis / 2 if single == 0
gen hnumdis_orig = hnumdis
if (`2' == 0) {
 summ hnumdis if single == 1
 *replace hnumdis = hnumdis / 7 if single == 1
 summ hnumdis if single == 0
 *replace hnumdis = hnumdis / 14 if single == 0
}

** create copy of "real" hhidpn
** NOTE: needs to be a "long"(!!)
capture drop *_copy
gen long hhidpn_copy = hhidpn

*assert hnumdis >= 0 & hnumdis <= 7
bys single: tab hnumdis, missing
loneway hnumdis hhidpn if single == 1
loneway hnumdis hhidpn if single == 0


summ log_inc_curr


**
** log_inc_curr set to missing for other household measures
**
capture drop myn
sort hhid wave hhidpn log_inc_curr hnumdis single hh_size 
bys hhid wave: gen myn = _n
summ log_inc_curr
replace log_inc_curr = . if myn != 1
summ log_inc_curr
summ hhid, det


gen log_inc_curr_copy = log_inc_curr
capture drop avg_age*
bys hhid wave: egen avg_age = mean(rage)
gen avg_age_squared = avg_age * avg_age

** test data is properly formulated
**replace log_inc_curr = . if rage != avg_age & rage < . & single == 1
**replace log_inc_curr = . if hh_size == 1 & single != 1
**sort hhid wave
**list hhidpn hhid shhidpn rage avg_age single if rage != avg_age & rage < . & single == 1
**assert(rage == avg_age) if rage < . & single == 1 & log_inc_curr < .
**assert(hh_size > 1) if single != 1 & log_inc_curr < .
** list hhidpn hhid shhidpn wave rage avg_age single hnumdis rnumdis if rage != avg_age & rage < . & single == 1


*drop if hhidpn == 14568020
*drop if hhidpn == 201539010
*drop if hhidpn == 205100020

drop hhidpn
replace shhidpn = 0 if shhidpn == .
egen long hhidpn = group(hhidpn_copy shhidpn)

**replace log_inc_curr = 0 if missing(log_inc_curr) & log_inc_perm < .

/**
 NOTE: THIS IS FOR CALIBRATION
 **/
summ hnumdis if log_c < ., det
local p50 = r(p50)
summ log_c_no_h if hnumdis > `p50', det
summ log_c_no_h if hnumdis <=  `p50', det
summ health_flow if log_c < ., det
summ health_flow if hnumdis > `p50' & log_c < ., det
summ health_flow if hnumdis <=  `p50' & log_c < ., det
gen c_no_h = total_consumption_flow - health_flow
summ c_no_h if hnumdis >   `p50' & log_c < ., det
summ c_no_h if hnumdis <=  `p50' & log_c < ., det
summ total_consumption_flow if hnumdis >   `p50' & log_c < ., det
summ total_consumption_flow if hnumdis <=  `p50' & log_c < ., det

summ health_flow if log_c < ., det
summ B_drugs if log_c < ., det
summ B_health_svc if log_c < ., det
summ B_medical_supply if log_c < ., det
summ B_health_ins if log_c < ., det





local var = "hnumdis"

foreach sample of numlist 0 {
 **foreach util of varlist log_inc_curr log_c log_c_nd log_c_no_h log_c_nd_no_h log_h 
 foreach util of varlist log_inc_curr log_c log_c_nd {
 **foreach util of varlist log_c log_c_nd {


  preserve

  capture drop myN
  sort hhidpn hnumdis
  by hhidpn: gen myN = _N
  replace log_inc_curr = . if myN == 1

  keep if log_inc_perm < .
  if ("`util'" != "log_inc_curr") {
   keep if log_c < . & log_c_nd < . & log_h < . & log_c_no_h < . & log_c_nd_no_h < . 

/**
   summ log_c, det
   replace log_c = r(p1) if log_c < r(p1)
   replace log_c = r(p99) if log_c > r(p99) & log_c < .

   summ log_c_nd, det
   replace log_c_nd = r(p1) if log_c_nd < r(p1)
   replace log_c_nd = r(p99) if log_c_nd > r(p99) & log_c_nd < .
 **/
  }

  summ log_inc_curr hnumdis

  di ""
  di " =============== " 
  di "doing var `var' `util' `sample' ..."
  di ${mu_`var'_`util'_`sample'}
  di " =============== " 

 **
 * de-mean all non-health variables
 ** NOTE: if health is included we get change in MU for inc in permanent income at MEAN health
 **
 foreach xvar of varlist rage rageSquared avg_age avg_age_squared hh_size wave log_inc_perm log_inc_curr {
  qui summ `xvar' if sample`sample' == 1
  qui replace `xvar' = `xvar' - r(mean)
 }


 capture drop *health_it*
 gen health_it = `var'
 replace hnumdis = hnumdis_orig 

 summ inc_curr, det
 summ `util' health_it avg_age avg_age_squared  single hh_size _Iwave*  if sample`sample' == 1

 areg `util' health_it avg_age avg_age_squared  single hh_size _Iwave* if sample`sample' == 1 , absorb(hhidpn) cluster(hhidpn)
 loneway health_it hhidpn if e(sample) == 1
 post_param "within_se" r(sd_w)
 est store base_`util'_`sample'


 capture drop ybarXwave
 capture drop ybarXh
 gen ybarXh = log_inc_perm * health_it
 areg `util' health_it ybarXh avg_age avg_age_squared  single hh_size _Iwave* if sample`sample' == 1 , absorb(hhidpn) cluster(hhidpn)
 loneway health_it hhidpn if e(sample) == 1
 post_param "within_se" r(sd_w)
 est store ybarXh_`util'_`sample'

 if ("`util'" == "log_h")  {
  /**
  reg `util' health_it ybarXh log_inc_perm avg_age avg_age_squared  single hh_size _Iwave* if sample`sample' == 1 ,  cluster(hhidpn)
  est store ybarXh_`util'_`sample'noFE
  reg `util' health_it log_inc_perm avg_age avg_age_squared  single hh_size _Iwave* if sample`sample' == 1 ,  cluster(hhidpn)
  est store ybarXh_`util'_`sample'noFE2
  **/
 }

 if ( ///
  "`util'" == "log_c"    | ///
  "`util'" == "log_c_nd" | ///
  "`util'" == "log_h"      ///
  )  {
  gen ybarXwave = log_inc_perm * wave
  summ `util' health_it ybarXwave avg_age avg_age_squared  single hh_size _Iwave* sample`sample'
  areg `util' health_it ybarXwave avg_age avg_age_squared  single hh_size _Iwave* if sample`sample' == 1 & log_inc_curr < ., absorb(hhidpn) cluster(hhidpn)
  est store inter1_`util'_`sample'

  areg `util' health_it ybarXwave avg_age avg_age_squared  single hh_size _Iwave* if sample`sample' == 1, absorb(hhidpn) cluster(hhidpn)
  est store inter1_`util'_`sample'2

  ** TODO: Should we include obs when log_inc_curr is missing?
  ** ANSWER: Probably not, to be consistent with rest of tables

 /** SAME AS ABOVE (AS EXPECTED)
  gen ybarXavg_age = log_inc_perm * avg_age
  areg `util' health_it ybarXwave avg_age avg_age_squared  single hh_size _Iwave* if sample`sample' == 1 & log_inc_curr < ., absorb(hhidpn) cluster(hhidpn)
  est store inter2_`util'_`sample'

  areg health_it ybarXwave avg_age avg_age_squared  single hh_size _Iwave* if sample`sample' == 1 & log_inc_curr < ., absorb(hhidpn) cluster(hhidpn)
  est store inter2_`util'_`sample'
 **/
 }

 areg `util' singleXhnumdis marriedXhnumdis avg_age avg_age_squared single hh_size _Iwave* if sample`sample' == 1 , absorb(hhidpn) cluster(hhidpn)
 test singleXhnumdis = marriedXhnumdis
 post_param "pval" r(p)
 loneway singleXhnumdis hhidpn if e(sample) == 1
 post_param "within_se" r(sd_w)
 loneway marriedXhnumdis hhidpn if e(sample) == 1
 post_param "within_se2" r(sd_w)
 est store strat_`util'

 di "Strat 2 ..."
 foreach v of varlist avg_age avg_age_squared single hh_size _Iwave* {
  gen s2aX`v' = single * `v'
  gen s2bX`v' = (1 - single) * `v'
 }
 di " ... DONE!"

 areg `util' singleXhnumdis marriedXhnumdis s2aX* s2bX* if sample`sample' == 1 , absorb(hhidpn) cluster(hhidpn)
 test singleXhnumdis = marriedXhnumdis
 post_param "pval" r(p)
 loneway singleXhnumdis hhidpn if e(sample) == 1
 post_param "within_se" r(sd_w)
 loneway marriedXhnumdis hhidpn if e(sample) == 1
 post_param "within_se2" r(sd_w)
 est store strat2_`util'

 drop s2*Xavg*
 drop s2*Xsingle*
 drop s2*X*wave*
 xi i.wave
 areg `util' singleXhnumdis marriedXhnumdis s2aX* s2bX* _I* if sample`sample' == 1 , absorb(hhidpn) cluster(hhidpn)
 test singleXhnumdis = marriedXhnumdis
 post_param "pval" r(p)
 loneway singleXhnumdis hhidpn if e(sample) == 1
 post_param "within_se" r(sd_w)
 loneway marriedXhnumdis hhidpn if e(sample) == 1
 post_param "within_se2" r(sd_w)
 est store strat2b_`util'

 gen singleXhnumdisXlogy = singleXhnumdis * log_inc_perm
 gen marriedXhnumdisXlogy = marriedXhnumdis * log_inc_perm
 areg `util' singleXhnumdis* marriedXhnumdis* avg_age avg_age_squared single hh_size _Iwave* if sample`sample' == 1 , absorb(hhidpn) cluster(hhidpn)
 test singleXhnumdis = marriedXhnumdis
 post_param "pval" r(p)
 test singleXhnumdisXlogy = marriedXhnumdisXlogy
 post_param "pval2" r(p)
 loneway singleXhnumdis hhidpn if e(sample) == 1
 post_param "within_se" r(sd_w)
 loneway marriedXhnumdis hhidpn if e(sample) == 1
 post_param "within_se2" r(sd_w)
 est store strat3_`util'

/**
 areg `util' $hlist $hlist2 avg_age avg_age_squared single hh_size _Iwave* if sample`sample' == 1 , absorb(hhidpn) cluster(hhidpn)
 test $hlist
 post_param "pval" r(p)
 test $hlist2
 post_param "pval2" r(p)
 est store strat3_`util'
 **/

 areg `util' $hlist $hlist2 $blist avg_age avg_age_squared single hh_size _Iwave* if sample`sample' == 1 , absorb(hhidpn) cluster(hhidpn)
 test $hlist $hlist2 $blist
 post_param "pval" r(p)
 est store strat4_`util'

 di "got here!, `sample'"
 count
 count if sample0 == 1
 count if single == 1
 tab single, missing
 count if sample0 == 1 & single == 1

 if (`2' == 0) {
 
 sum `util' hnumdis avg_age avg_age_squared  single hh_size _Iwave* if sample`sample' == 1 & single == 1

 areg `util' hnumdis avg_age avg_age_squared  single hh_size _Iwave* if sample`sample' == 1 & single == 1, absorb(hhidpn) cluster(hhidpn)
 loneway hnumdis hhidpn if e(sample) == 1
 post_param "within_se" r(sd_w)
 est store single_`util'_`sample'

 capture drop ybarXwave
 capture drop ybarXh
 gen ybarXh = log_inc_perm * hnumdis
 areg `util' hnumdis ybarXh avg_age avg_age_squared  single hh_size _Iwave* if sample`sample' == 1 & single == 1, absorb(hhidpn) cluster(hhidpn)
 loneway hnumdis hhidpn if e(sample) == 1
 post_param "within_se" r(sd_w)
 est store single_y_`util'_`sample'

 areg `util' hnumdis avg_age avg_age_squared  single hh_size _Iwave* if sample`sample' == 1 & alwaysSingle == 1, absorb(hhidpn) cluster(hhidpn)
 loneway hnumdis hhidpn if e(sample) == 1
 post_param "within_se" r(sd_w)
 est store asingle_`util'_`sample'

 capture drop ybarXwave
 capture drop ybarXh
 gen ybarXh = log_inc_perm * hnumdis
 areg `util' hnumdis ybarXh avg_age avg_age_squared  single hh_size _Iwave* if sample`sample' == 1 & alwaysSingle == 1, absorb(hhidpn) cluster(hhidpn)
 loneway hnumdis hhidpn if e(sample) == 1
 post_param "within_se" r(sd_w)
 est store asingle_y_`util'_`sample'

 areg `util' hnumdis avg_age avg_age_squared  single hh_size _Iwave* if sample`sample' == 1 & single != 1, absorb(hhidpn) cluster(hhidpn)
 loneway hnumdis hhidpn if e(sample) == 1
 post_param "within_se" r(sd_w)
 est store married_`util'_`sample'

 capture drop ybarXwave
 capture drop ybarXh
 gen ybarXh = log_inc_perm * hnumdis
 areg `util' hnumdis ybarXh avg_age avg_age_squared  single hh_size _Iwave* if sample`sample' == 1 & single != 1, absorb(hhidpn) cluster(hhidpn)
 loneway hnumdis hhidpn if e(sample) == 1
 post_param "within_se" r(sd_w)
 est store married_y_`util'_`sample'

 }

 restore

di "ending foreach util"
** end foreach util var
}

di "ending foreach sample var"
** end foreach sample var
}


** base_log_c_no_h_0 ybarXh_log_c_no_h_0 ///
**  base_log_c_nd_no_h_0 ybarXh_log_c_nd_no_h_0 

if (`2' == 0) {

estout ///
 strat* ///
 using ${OUTPUT_DIRECTORY}/table10_strat`2'.txt , drop(_* *age* single hh_size)  ///
 stats(within_se within_se2 pval pval2 pval3 r2 N, fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 
est drop strat*

estout ///
 single* married* asingle* ///
 using ${OUTPUT_DIRECTORY}/table10_subs`2'.txt , drop(_* *age* single hh_size)  ///
 stats(within_se within_se2 pval pval2 pval3 r2 N, fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 
est drop single* married* asingle*

}


estout ///
 base_log_inc_curr_0 ybarXh_log_inc_curr_0 ///
 base_log_c_0 ybarXh_log_c_0 ///
 base_log_c_nd_0 ybarXh_log_c_nd_0 ///
 *inter* ///
 using ${OUTPUT_DIRECTORY}/table10_cams`2'.txt , drop(_* *age* single hh_size)  ///
 stats(within_se r2 N, fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 



**estout ybarX*0* ///
** using ${OUTPUT_DIRECTORY}/tableYY_cams.txt , drop(_* *age* single hh_size)  ///
** stats(r2 N, fmt(%9.3f)) modelwidth(15) ///
** cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 

**estout base*_2 inter*_0 inter*_2 ///
** using ${OUTPUT_DIRECTORY}/tableXX_cams.txt , drop(_* *age* single hh_size)  ///
** stats(r2 N, fmt(%9.3f)) modelwidth(15) ///
** cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 

replace log_inc_curr = log_inc_curr_copy
capture drop log_inc_curr_copy
replace hhidpn = hhidpn_copy

exit


**  *clogit* other_inters other_inters2 curr_inc edyrs
** log_inc_curr rage ybarXrage)
estout *_3 /// 
   using /bbkinghome/noto/stateDependentUtility/rand/table9B_`var'.txt, keep(health_it) ///
 stats(r2 N within_se MU_inc , fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 
estout *_3c /// 
   using /bbkinghome/noto/stateDependentUtility/rand/table9B_noFE_`var'.txt, keep(health_it log_inc_perm) ///
 stats(r2 N within_se MU_inc , fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 
estout *_3fd /// 
   using /bbkinghome/noto/stateDependentUtility/rand/table9B_FD_`var'.txt, keep(D.health_it) ///
 stats(r2 N , fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 

estout *_12  ///
   using /bbkinghome/noto/stateDependentUtility/rand/table9C_`var'.txt, keep(health_it) ///
 stats(r2 N ind_N within_se MU_inc one_b_over_muinc one_b_se onesd_b_over_muinc onesd_b_se , fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 
estout *_12c /// 
   using /bbkinghome/noto/stateDependentUtility/rand/table9C_noFE_`var'.txt, keep(health_it log_inc_perm) ///
 stats(r2 N within_se MU_inc , fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 
estout *_12fd /// 
   using /bbkinghome/noto/stateDependentUtility/rand/table9C_FD_`var'.txt, keep(D.health_it) ///
 stats(r2 N within_se MU_inc , fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 

estout *_13  ///
   using /bbkinghome/noto/stateDependentUtility/rand/table9D_`var'.txt, keep(health_it) ///
 stats(r2 N ind_N within_se MU_inc one_b_over_muinc one_b_se onesd_b_over_muinc onesd_b_se , fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 
estout *_13c /// 
   using /bbkinghome/noto/stateDependentUtility/rand/table9D_noFE_`var'.txt, keep(health_it log_inc_perm) ///
 stats(r2 N within_se MU_inc , fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 
estout *_13fd /// 
   using /bbkinghome/noto/stateDependentUtility/rand/table9D_FD_`var'.txt, keep(D.health_it) ///
 stats(r2 N within_se MU_inc , fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 


di "ending foreach health var"
** end foreach healt var
}
