
set more off
set seed 12345
est clear

/**
preserve
keep if sample0 == 1
save ~/nonlinear_data.dta, replace
restore
exit
**/

global reg = "areg"
global options = " absorb(hhidpn) cluster(hhid) "
global max_sample = 14

*clear
*set memory 1000m
*use ~/nonlinear_data
*keep if sample0 == 1

capture program drop mfx_repost
program define mfx_repost, eclass
 matrix e_V = diag(e_V)
 ereturn repost b=e_b V=e_V
end

capture program drop base_bootstrap
program define base_bootstrap, eclass sortpreserve
 
  

 $reg rwhappy  ybar_iXhealth_it health_it dummyY_iXhealth_it rage rageSquared single hh_size _Iwave* if sample0 == 1 , $options
 est store   rnumdis_rwhappy_0
 do calcMUincFE rnumdis rwhappy 0 0
 est restore rnumdis_rwhappy_0
 loneway health_it hhidpn if e(sample) == 1
 local sd = r(sd_w)
 lincom `sd' * _b[ybar_iXhealth_it] / ${mu_rnumdis_rwhappy_0}

 tempname b V
 matrix `b' = e(b)
 matrix `V' = e(V)
 matrix `b'[1,1] = r(estimate)
 matrix `V'[1,1] = r(se)*r(se)
 ereturn repost b=`b' V=`V'

/**
 tempname obs dof
 local `obs' = e(obs)
 local `dof' = e(dof)
 tempname b V
 matrix `V' = [r(se)*r(se)]
 matrix `b' = [r(estimate)]
 matrix list `V'
 matrix list `b'
 matrix rownames `V' = gamma1
 matrix colnames `V' = gamma1
 matrix rownames `b' = y1
 matrix colnames `b' = gamma1
 di "posting results ..."
 tempname esample
 gen `esample' = sample0
 ereturn post `b' `V', esample(`esample') obs(``obs'') dof(``dof'')
 di "done."
**/
end





**
* FOR each health variable ...
*  FOR each sample ...
*   FOR each utility measure ...


rename rseatBelts rbelts
rename rfracPrevExt rprev


* no hnumdis anymore
foreach var of varlist rnumdis radl_tot riadl_tot rofl_tot r_sh rnd_wpsy rnumdis6 med_tot rh_idx {
  ** (other diseases) lng_db_st lng_db_st_sev lung_diab lung_diab_sev

 forvalues sample = 0(1)$max_sample {

  ** foreach util of varlist rwhappy rcesd4 rcesd rfracPrev rbelts rprev r_sh_u log_h log_c_tot log_c log_c_less_h 
  foreach util of varlist rwhappy rcesd4 rcesd rbelts rprev {

   if (("`var'" != "rnumdis" & `sample' > 0) | /// 
       ("`var'" != "rnumdis" & ("`util'" != "rwhappy")) | ///
       (`sample' >= 1 & ("`util'" != "rwhappy") ) ///
         ) {
     di "skipping `var', `util', `sample', `alpha' ..."
   }
   else {


  di "begin else"

  di ""
  di " =============== " 
  di "doing var `var' `util' `sample' ..."
  di ${mu_`var'_`util'_`sample'}
  di " =============== " 

 **
 * de-mean all non-health variables
 ** NOTE: if health is included we get change in MU for inc in permanent income at MEAN health
 **
 replace log_inc_perm = log(inc_perm / 1000)
 replace wealth_perm = . if wealth_perm < 1000
 capture drop log_wealth_perm
 gen log_wealth_perm = log(wealth_perm)
 foreach xvar of varlist single rage rageSquared hh_size wave _Iw* log_wealth_perm log_inc_perm dummy_inc_perm dummy_inc_curr raedyrs log_c {
  qui summ `xvar' if sample`sample' == 1
  qui replace `xvar' = `xvar' - r(mean)
 }
 summ inc_perm if sample0 == 1
 replace log_inc_curr = log_inc_curr - log(r(mean))

 capture drop *health_it


 gen double ybar_iXhealth_it   = log_inc_perm * `var'
 ** gen dummyY_iXhealth_it = dummy_inc_perm * `var'
 gen dummyY_iXhealth_it = 0
 assert(dummy_inc_perm == 0)
 
 gen health_it = `var'

 ** these get rid of singletons(!)
 local s = `sample'
 if ("`util'" == "rbelts") {
   local s = 12
 }
 if ("`util'" == "rprev") {
   local s = 13
 }

 $reg `util'  ybar_iXhealth_it health_it dummyY_iXhealth_it rage rageSquared single hh_size _Iwave* if sample`s' == 1 , $options
 est store   `var'_`util'_`s'
 do calcMUincFE `var' `util' `s' 1
 est restore `var'_`util'_`s'
 loneway health_it hhidpn if e(sample) == 1
 local sd = r(sd_w)
 lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`s'}
 global one_b_over_muinc = r(estimate)
 global one_b_se = r(se)
 lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`s'}
 global onesd_b_over_muinc = r(estimate)
 global onesd_b_se = r(se)
 global within_se = `sd'
 global MU_inc = ${mu_`var'_`util'_`s'}
 global MU_inc_se = ${mu_`var'_`util'_`s'_se}
 rand_areg
 est store `var'_`util'_`s'


/** base_bootstrap
 ereturn display
 ereturn list
 base_bootstrap 
 bootstrap _b[ybar_iXhealth_it], reps(200) cluster(hhidpn): base_bootstrap rwhappy
 bootstrap _b[ybar_iXhealth_it], reps(200): base_bootstrap rwhappy
**/

 if ("`var'" == "rnumdis" & "`util'" == "rwhappy" & `s' == 0) {
  global mu_baseline = ${mu_`var'_`util'_`s'}
 }

 if ("`var'" == "rnumdis" & `sample' == 0 & "`util'" == "rwhappy") {

  **foreach a of numlist 50 99 100 101 150 200 300 500 1000 {
  **foreach a of numlist 100 {
  foreach a of numlist 100 50 200 300 500 1000 {

  preserve
  di "############"
  di " alpha: `a'"
  di "############"

  local alpha = `a' / 100

  if (`alpha' != 1) { 
   summ log_inc_perm
   local sigma_x = r(sd)
   local mu_x = r(mean)
   rename log_inc_perm log_inc_perm_old
   gen double log_inc_perm = ( (inc_perm/1000) ^ (1 - `alpha')) / (1 - `alpha')
   drop log_inc_perm_old

   summ log_inc_perm
   **replace log_inc_perm = log_inc_perm * 1e25
   **replace log_inc_perm = log_inc_perm * (`sigma_x' / r(sd))
   summ log_inc_perm
  }
  else {
   ** don't replace log_inc_perm 
  }

 qui summ log_inc_perm if sample`sample' == 1
 qui replace log_inc_perm = log_inc_perm - r(mean)
  
 drop ybar_iXhealth_it
 gen double ybar_iXhealth_it = log_inc_perm * `var'

 $reg `util'  ybar_iXhealth_it health_it dummyY_iXhealth_it rage rageSquared single hh_size _Iwave* if sample`sample' == 1 , $options
 est store  alpha_`a'
 do calcMUincFE `var' `util' `sample' 1
 est restore  alpha_`a'
 loneway health_it hhidpn if e(sample) == 1
 local sd = r(sd_w)
 lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
 global one_b_over_muinc = r(estimate)
 global one_b_se = r(se)
 lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
 global onesd_b_over_muinc = r(estimate)
 global onesd_b_se = r(se)
 global within_se = `sd'
 global MU_inc = ${mu_`var'_`util'_`sample'}
 global MU_inc_se = ${mu_`var'_`util'_`sample'_se}
 rand_areg
 est store alpha_`a'
 

 /**
  ***
 capture drop xb 
 clogit `util' ybar_iXhealth_it health_it single hh_size rage rageSquared _Iw* if sample0 == 1, group(hhidpn) cluster(hhidpn) 
 keep if e(sample) == 1
 est store clogit_a
 matrix e_b = e(b)
 matrix e_V = vecdiag(e(V)) 

 predict pc1, pc1
 capture drop myn
 bys hhidpn: gen myn = _n
 bys hhidpn: gen rand_n = 1+floor(_N*uniform())

 bys hhidpn: replace ybar_iXhealth_it = ybar_iXhealth_it + 1e-3 if rand_n == _n
 predict pc2, pc1
 bys hhidpn: replace health_it = health_it + 1e-3 if rand_n == _n
 bys hhidpn: replace ybar_iXhealth_it = ybar_iXhealth_it - 1e-3 if rand_n == _n
 predict pc3, pc1
 gen double deriv = (pc2 - pc1) / 1e-3
 summ deriv if myn == rand_n
 local beta_1_mean = r(mean)
 local beta_1_sd   = r(sd)
 gen double deriv2 = (pc3 - pc1) / 1e-3
 summ deriv2 if myn == rand_n
 local beta_0_mean = r(mean)
 local beta_0_sd   = r(sd)
 matrix e_V[1,1] = e_V[1,1] * ((`beta_1_mean' / e_b[1,1])^2)
 matrix e_V[1,2] = e_V[1,2] * ((`beta_0_mean' / e_b[1,2])^2)
 matrix e_b[1,1] = `beta_1_mean'
 matrix e_b[1,2] = `beta_0_mean'
 mfx_repost

 loneway health_it hhidpn if e(sample) == 1
 local sd = r(sd_w)
 lincom _b[ybar_iXhealth_it] / ${mu_baseline}
 global one_b_over_muinc = r(estimate)
 global one_b_se = r(se)
 lincom `sd' * _b[ybar_iXhealth_it] / ${mu_baseline}
 global onesd_b_over_muinc = r(estimate)
 global onesd_b_se = r(se)
 global within_se = `sd'
 global MU_inc =  ${mu_baseline}
 rand_areg
 est store clogit_`a'
 ***
 **/

 restore

 di "ending foreach alpha"
 ** end foreach alpha
 }

 estout alpha_*  ///
  using /bbkinghome/noto/stateDependentUtility/rand/table6_nonlinear.txt, keep(health_it ybar_iXhealth_it) ///
  stats(MU_inc MU_inc_se r2 N ind_N within_se onesd_b_over_muinc onesd_b_se, fmt(%9.3f)) modelwidth(15) ///
  cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 


 }




if ("`var'" == "rnumdis" & "`util'" == "rwhappy") {
   reg log_inc_curr health_it dummyY_iXhealth_it isfemale isblack rage rageSquared single hh_size _Iwave* if sample`sample' == 1 , cluster(hhidpn)
    est store sample`sample'_curr_noFE
   $reg log_inc_curr health_it dummyY_iXhealth_it rage rageSquared single hh_size _Iwave* if sample`sample' == 1 , $options
    est store sample`sample'_curr_FE
}


*************
* baseline cases
*************
  if ("`var'" == "rnumdis" & ("`util'" == "rcesd" | "`util'" == "rwhappy" | "`util'" == "rcesd4") & `sample' == 0) {

   if ("`util'" == "rwhappy") {


     preserve
     ** interact everything with income (!!) 
     gen double ybarXhh_size = log_inc_perm * hh_size
     gen double ybarXrage = log_inc_perm * rage
     gen double ybarXsingle = log_inc_perm * single
     $reg `util' *health_it ybarXhh_size ybarXsingle single hh_size rage rageSquared _Iw* if sample`sample' == 1, $options
     est store other_inters
     do calcMUincFE `var' `util' `sample' 0
     est restore other_inters
     loneway health_it hhidpn if e(sample) == 1
     local sd = r(sd_w)
     lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global one_b_over_muinc = r(estimate)
     global one_b_se = r(se)
     lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global onesd_b_over_muinc = r(estimate)
     global onesd_b_se = r(se)
     global within_se = `sd'
     global MU_inc = ${mu_`var'_`util'_`sample'}
     global MU_inc_se = ${mu_`var'_`util'_`sample'_se}
     rand_areg
     est store other_inters
     restore

     preserve
     ** interact everything with income (!!) 
     gen ybarXhh_size = log_inc_perm * hh_size
     gen ybarXrage = log_inc_perm * rage
     gen ybarXsingle = log_inc_perm * single
     $reg `util' *health_it ybarXhh_size ybarXsingle ybarXrage single hh_size rage rageSquared _Iw* if sample`sample' == 1, $options
     est store other_inters2
     do calcMUincFE `var' `util' `sample' 0
     est restore other_inters2
     loneway health_it hhidpn if e(sample) == 1
     local sd = r(sd_w)
     lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global one_b_over_muinc = r(estimate)
     global one_b_se = r(se)
     lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global onesd_b_over_muinc = r(estimate)
     global onesd_b_se = r(se)
     global within_se = `sd'
     global MU_inc = ${mu_`var'_`util'_`sample'}
     global MU_inc_se = ${mu_`var'_`util'_`sample'_se}
     rand_areg
     est store other_inters2
     restore


     $reg `util' *health_it log_inc_curr dummy_inc_curr single hh_size rage rageSquared _Iw* if sample`sample' == 1, $options
     est store curr_inc
     do calcMUincFE `var' `util' `sample' 0
     est restore curr_inc
     loneway health_it hhidpn if e(sample) == 1
     local sd = r(sd_w)
     lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global one_b_over_muinc = r(estimate)
     global one_b_se = r(se)
     lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global onesd_b_over_muinc = r(estimate)
     global onesd_b_se = r(se)
     global within_se = `sd'
     global MU_inc = ${mu_`var'_`util'_`sample'}
     global MU_inc_se = ${mu_`var'_`util'_`sample'_se}
     rand_areg
     est store curr_inc

     preserve
     replace ybar_iXhealth_it = raedyrs * health_it
     replace log_inc_perm = raedyrs 
     $reg `util'  ybar_iXhealth_it health_it dummyY_iXhealth_it rage rageSquared single hh_size _Iwave* if sample`sample' == 1 , $options
     est store edyrs
     do calcMUincFE `var' `util' `sample' 0
     est restore edyrs
     loneway health_it hhidpn if e(sample) == 1
     local sd = r(sd_w)
     lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global one_b_over_muinc = r(estimate)
     global one_b_se = r(se)
     lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global onesd_b_over_muinc = r(estimate)
     global onesd_b_se = r(se)
     global within_se = `sd'
     global MU_inc = ${mu_`var'_`util'_`sample'}
     global MU_inc_se = ${mu_`var'_`util'_`sample'_se}
     rand_areg
     est store edyrs
     restore


     preserve
     summ log_wealth_perm
     replace ybar_iXhealth_it = log(wealth_perm) * health_it
     replace log_inc_perm = log(wealth_perm)
     $reg `util'  ybar_iXhealth_it health_it rage rageSquared single hh_size _Iwave* if sample`sample' == 1 , $options
     est store wealth
     do calcMUincFE `var' `util' `sample' 0
     est restore wealth
     loneway health_it hhidpn if e(sample) == 1
     local sd = r(sd_w)
     lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global one_b_over_muinc = r(estimate)
     global one_b_se = r(se)
     lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global onesd_b_over_muinc = r(estimate)
     global onesd_b_se = r(se)
     global within_se = `sd'
     global MU_inc = ${mu_`var'_`util'_`sample'}
     global MU_inc_se = ${mu_`var'_`util'_`sample'_se}
     rand_areg
     est store wealth
     restore

/**
     preserve
     replace ybar_iXhealth_it = log(wealth_all_perm) * health_it
     replace log_inc_perm = log(wealth_all_perm)
     $reg `util'  ybar_iXhealth_it health_it rage rageSquared single hh_size _Iwave* if sample`sample' == 1 , $options
     est store wealth_all
     do calcMUincFE `var' `util' `sample' 0
     est restore wealth_all
     loneway health_it hhidpn if e(sample) == 1
     local sd = r(sd_w)
     lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global one_b_over_muinc = r(estimate)
     global one_b_se = r(se)
     lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global onesd_b_over_muinc = r(estimate)
     global onesd_b_se = r(se)
     global within_se = `sd'
     global MU_inc = ${mu_`var'_`util'_`sample'}
     global MU_inc_se = ${mu_`var'_`util'_`sample'_se}
     rand_areg
     est store wealth_all
     restore
**/

     foreach pct of numlist 0 10 {
     preserve
     replace ybar_iXhealth_it = log_inc_w`pct'pct_perm * health_it
     replace log_inc_perm = log_inc_w`pct'pct_perm
     $reg `util'  ybar_iXhealth_it health_it rage rageSquared single hh_size _Iwave* if sample`sample' == 1 , $options
     est store w`pct'pct
     do calcMUincFE `var' `util' `sample' 0
     est restore w`pct'pct
     loneway health_it hhidpn if e(sample) == 1
     local sd = r(sd_w)
     lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global one_b_over_muinc = r(estimate)
     global one_b_se = r(se)
     lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global onesd_b_over_muinc = r(estimate)
     global onesd_b_se = r(se)
     global within_se = `sd'
     global MU_inc = ${mu_`var'_`util'_`sample'}
     global MU_inc_se = ${mu_`var'_`util'_`sample'_se}
     rand_areg
     est store w`pct'pct
     restore
     } 


     ** interact wave FE with perm inc
     preserve
     xi i.wave
     foreach xvar of varlist _Iw* {
      qui summ `xvar' if sample`sample' == 1
      qui replace `xvar' = `xvar' - r(mean)
      gen `xvar'Xlog_inc_perm = `xvar' * log_inc_perm
     }
     $reg `util' *health_it single hh_size rage rageSquared _I* if sample`sample' == 1, $options
     est store ybarXwaveFE
     do calcMUincFE `var' `util' `sample' 0
     est restore ybarXwaveFE
     loneway health_it hhidpn if e(sample) == 1
     local sd = r(sd_w)
     lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global one_b_over_muinc = r(estimate)
     global one_b_se = r(se)
     lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global onesd_b_over_muinc = r(estimate)
     global onesd_b_se = r(se)
     global within_se = `sd'
     global MU_inc = ${mu_`var'_`util'_`sample'}
     global MU_inc_se = ${mu_`var'_`util'_`sample'_se}
     rand_areg
     est store ybarXwaveFE
     restore

     ** interact PE with year
     preserve
     gen ybarXwave = log_inc_perm * wave
     summ ybarXwave if sample`sample' == 1
     replace ybarXwave = ybarXwave - r(mean)
     summ ybarXwave if sample`sample' == 1
     $reg `util' *health_it ybarXwave single hh_size rage rageSquared _Iw* if sample`sample' == 1, $options
     summ ybarXwave *health_it log_inc_perm wave if e(sample) == 1
     est store ybarXwave
     do calcMUincFE `var' `util' `sample' 0
     est restore ybarXwave
     loneway health_it hhidpn if e(sample) == 1
     local sd = r(sd_w)
     lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global one_b_over_muinc = r(estimate)
     global one_b_se = r(se)
     lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global onesd_b_over_muinc = r(estimate)
     global onesd_b_se = r(se)
     global within_se = `sd'
     global MU_inc = ${mu_`var'_`util'_`sample'}
     global MU_inc_se = ${mu_`var'_`util'_`sample'_se}
     rand_areg
     est store ybarXwave
     restore



   forvalues d = 1(1)5 {
     ** H - <=2 diseaes; S - >2 diseases
     preserve
     replace health_it = (rnumdis >= `d')
     replace health_it = . if rnumdis == .
     replace ybar_iXhealth_it = health_it * log_inc_perm  
     $reg `util' *health_it single hh_size rage rageSquared _Iw* if sample`sample' == 1, $options
     est store hilo_ge`d'
     do calcMUincFE `var' `util' `sample' 0
     est restore hilo_ge`d'
     loneway health_it hhidpn if e(sample) == 1
     local sd = r(sd_w)
     lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global one_b_over_muinc = r(estimate)
     global one_b_se = r(se)
     lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global onesd_b_over_muinc = r(estimate)
     global onesd_b_se = r(se)
     global within_se = `sd'
     global MU_inc = ${mu_`var'_`util'_`sample'}
     global MU_inc_se = ${mu_`var'_`util'_`sample'_se}
     rand_areg
     est store hilo_ge`d'
     restore
   }

/**
     preserve
     $reg `util'  ybar_iXhealth_it health_it rage rageSquared single hh_size _Iwave* if sample`sample' == 1 & log_c_no_h < . , $options
     est store cams_c
     do calcMUincFE `var' `util' `sample' 0
     est restore cams_c
     loneway health_it hhidpn if e(sample) == 1
     local sd = r(sd_w)
     lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global one_b_over_muinc = r(estimate)
     global one_b_se = r(se)
     lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global onesd_b_over_muinc = r(estimate)
     global onesd_b_se = r(se)
     global within_se = `sd'
     global MU_inc = ${mu_`var'_`util'_`sample'}
     global MU_inc_se = ${mu_`var'_`util'_`sample'_se}
     rand_areg
     est store cams_c
     restore

     preserve
     **replace ybar_iXhealth_it = log_c_no_h * health_it
     **replace log_inc_perm = log_c_no_h
     $reg `util'  ybar_iXhealth_it health_it log_c_no_h rage rageSquared single hh_size _Iwave* if sample`sample' == 1 , $options
     est store cams_c2
     do calcMUincFE `var' `util' `sample' 0
     est restore cams_c2
     loneway health_it hhidpn if e(sample) == 1
     local sd = r(sd_w)
     lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global one_b_over_muinc = r(estimate)
     global one_b_se = r(se)
     lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global onesd_b_over_muinc = r(estimate)
     global onesd_b_se = r(se)
     global within_se = `sd'
     global MU_inc = ${mu_`var'_`util'_`sample'}
     global MU_inc_se = ${mu_`var'_`util'_`sample'_se}
     rand_areg
     est store cams_c2
     restore



     preserve
     replace ybar_iXhealth_it = log_c_no_h * health_it
     replace log_inc_perm = log_c_no_h
     $reg `util'  ybar_iXhealth_it health_it log_c_no_h rage rageSquared single hh_size _Iwave* if sample`sample' == 1 , $options
     est store cams_cons
     do calcMUincFE `var' `util' `sample' 0
     est restore cams_cons
     loneway health_it hhidpn if e(sample) == 1
     local sd = r(sd_w)
     lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global one_b_over_muinc = r(estimate)
     global one_b_se = r(se)
     lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global onesd_b_over_muinc = r(estimate)
     global onesd_b_se = r(se)
     global within_se = `sd'
     global MU_inc = ${mu_`var'_`util'_`sample'}
     global MU_inc_se = ${mu_`var'_`util'_`sample'_se}
     rand_areg
     est store cams_cons
     restore

     preserve
     replace ybar_iXhealth_it = log_c_no_h * health_it
     replace log_inc_perm = log_c_no_h
     $reg `util'  ybar_iXhealth_it health_it log_c_no_h rage rageSquared single hh_size _Iwave* if sample1 == 1 , $options
     est store cams_cons2
     do calcMUincFE `var' `util' `sample' 0
     est restore cams_cons2
     loneway health_it hhidpn if e(sample) == 1
     local sd = r(sd_w)
     lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global one_b_over_muinc = r(estimate)
     global one_b_se = r(se)
     lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global onesd_b_over_muinc = r(estimate)
     global onesd_b_se = r(se)
     global within_se = `sd'
     global MU_inc = ${mu_`var'_`util'_`sample'}
     global MU_inc_se = ${mu_`var'_`util'_`sample'_se}
     rand_areg
     est store cams_cons2
     restore

     preserve
     replace ybar_iXhealth_it = log_c_no_h * health_it
     replace log_inc_perm = log_c_no_h
     reg `util'  ybar_iXhealth_it health_it log_c_no_h rage rageSquared single hh_size _Iwave* if sample0 == 1 , cluster(hhidpn)
     est store cams_cons3
     **do calcMUincFE `var' `util' `sample' 0
     **est restore cams_cons3
     loneway health_it hhidpn if e(sample) == 1
     local sd = r(sd_w)
     lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global one_b_over_muinc = r(estimate)
     global one_b_se = r(se)
     lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
     global onesd_b_over_muinc = r(estimate)
     global onesd_b_se = r(se)
     global within_se = `sd'
     global MU_inc = ${mu_`var'_`util'_`sample'}
     global MU_inc_se = ${mu_`var'_`util'_`sample'_se}
     rand_areg
     est store cams_cons3
     restore
**/

/**
 preserve
 capture drop *health_it
 capture drop rnumdisw 
 if ("`util'" == "rcesd4") {
  gen rnumdisw = rnumdis_wgt_rcesd4
 }
 if ("`util'" == "rcesd") {
  gen rnumdisw = rnumdis_wgt_rcesd
 }
 if ("`util'" == "rwhappy") {
  gen rnumdisw = rnumdis_wgt_rwhappy
 }
 gen ybar_iXhealth_it   = log_inc_perm * rnumdisw
 gen dummyY_iXhealth_it = dummy_inc_perm * rnumdisw
 gen health_it = rnumdisw
 local var2 = "rnumdisw"

 $reg `util'  ybar_iXhealth_it health_it dummyY_iXhealth_it rage rageSquared single hh_size _Iwave* if sample`sample' == 1 , $options
 est store   rnumdisw_`util'_`sample'
 do calcMUincFE rnumdisw `util' `sample' 0
 est restore rnumdisw_`util'_`sample'
 loneway health_it hhidpn if e(sample) == 1
 local sd = r(sd_w)
 lincom _b[ybar_iXhealth_it] / ${mu_rnumdisw_`util'_`sample'}
 global one_b_over_muinc = r(estimate)
 global one_b_se = r(se)
 lincom `sd' * _b[ybar_iXhealth_it] / ${mu_rnumdisw_`util'_`sample'}
 global onesd_b_over_muinc = r(estimate)
 global onesd_b_se = r(se)
 global within_se = `sd'
 global MU_inc = ${mu_rnumdisw_`util'_`sample'}
 rand_areg
 est store rnumdisw_`util'_`sample'
 restore
**/

   }


  }




  



 if ("`var'" == "rnumdis" & `sample' == 0 & ("`util'" == "rcesd" | "`util'" == "rwhappy" | "`util'" == "rcesd4") ) {
  di "beginning spouse ..."

  gen shealth_it = snumdis
  gen double ybar_iXshealth_it = log_inc_perm * snumdis
  gen dummyY_iXshealth_it = dummy_inc_perm * snumdis

 $reg `util' ybar_iXhealth_it health_it ybar_iXshealth_it shealth_it rage rageSquared single hh_size _Iwave* if sample0 == 1 , $options
 test ybar_iXhealth_it = ybar_iXshealth_it
 est store   sp_`var'_`util'_`sample'
 do calcMUincFE `var' `util' 0 0
 est restore sp_`var'_`util'_`sample'
 loneway health_it hhidpn if e(sample) == 1
 local sd = r(sd_w)
 lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
 global one_b_over_muinc = r(estimate)
 global one_b_se = r(se)
 lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
 global onesd_b_over_muinc = r(estimate)
 global onesd_b_se = r(se)
 global within_se = `sd'
 global MU_inc = ${mu_`var'_`util'_`sample'}
     global MU_inc_se = ${mu_`var'_`util'_`sample'_se}
 rand_areg
/**
 lincom _b[ybar_iXshealth_it] / ${mu_`var'_`util'_`sample'}
 global one_bs_over_muinc = r(estimate)
 global one_bs_se = r(se)
 lincom `sd' * _b[ybar_iXshealth_it] / ${mu_`var'_`util'_`sample'}
 global onesd_bs_over_muinc = r(estimate)
 global onesd_bs_se = r(se)
 global sp_within_se = `sd'
 rand_spouse_areg
**/
 est store sp_`var'_`util'_`sample'


/**
 $reg `util' ybar_iXhealth_it health_it ybar_iXshealth_it shealth_it rage rageSquared single hh_size _Iwave* if sample14 == 1, $options
 est store   sp_`var'_`util'_`sample'2
 do calcMUincFE `var' `util' 14 0
 est restore sp_`var'_`util'_`sample'2
 loneway health_it hhidpn if e(sample) == 1
 local sd = r(sd_w)
 lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
 global one_b_over_muinc = r(estimate)
 global one_b_se = r(se)
 lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
 global onesd_b_over_muinc = r(estimate)
 global onesd_b_se = r(se)
 global within_se = `sd'
 global MU_inc = ${mu_`var'_`util'_`sample'}
     global MU_inc_se = ${mu_`var'_`util'_`sample'_se}
 rand_areg
 est store sp_`var'_`util'_`sample'2
**/


 di "ending spouse ..."
 }

 if (`sample' == 0 & "`var'" == "rnumdis" & ("`util'" == "rcesd" | "`util'" == "rwhappy" | "`util'" == "rcesd4") ) {
  ** see table3.20071111.do
  **
  * no covariates
  $reg `util' ybar_iXhealth_it health_it dummyY_iXhealth_it  _Iwave* if sample`sample' == 1 , $options
  est store   `var'_`util'_`sample'_noxs
  do calcMUincFE `var' `util' `sample' 0
  est restore `var'_`util'_`sample'_noxs
  loneway health_it hhidpn if e(sample) == 1
  local sd = r(sd_w)
  lincom _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
  global one_b_over_muinc = r(estimate)
  global one_b_se = r(se)
  lincom `sd' * _b[ybar_iXhealth_it] / ${mu_`var'_`util'_`sample'}
  global onesd_b_over_muinc = r(estimate)
  global onesd_b_se = r(se)
  global within_se = `sd'
  global MU_inc = ${mu_`var'_`util'_`sample'}
  global MU_inc_se = ${mu_`var'_`util'_`sample'_se}
  rand_areg
  est store `var'_`util'_`sample'_noxs
 }


 capture drop *health_it


di "ending else"
** end else
}



di "ending foreach util"
** end foreach util var
}

di "ending foreach sample var"
** end foreach sample var
}

di "ending foreach health var"
** end foreach health var
}




estout rnumdis_rwhappy_0_noxs rnumdis_rwhappy_0 ///
 using /bbkinghome/noto/stateDependentUtility/rand/table4_baseline.txt, keep(ybar_iXhealth_it health_it) ///
 stats(MU_inc MU_inc_se r2 N ind_N within_se one_b_over_muinc one_b_se onesd_b_over_muinc onesd_b_se , fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 


**  curr_inc edyrs
** log_inc_curr rage ybarXrage)
estout  rnumdis_rwhappy_0  rnumdis_rcesd_0 rnumdis_rcesd4_0 rnumdis_rwhappy_0 rnumdis_rprev_13 rnumdis_rbelts_12 ///
   using /bbkinghome/noto/stateDependentUtility/rand/table7_utils.txt, keep(ybar_iXhealth_it health_it ) ///
 stats(MU_inc MU_inc_se r2 N ind_N within_se onesd_b_over_muinc onesd_b_se, fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 

** lung_diab, rnumdisw_rwhappy_0 

estout rnumdis_rwhappy_0 *l_tot_rwhappy_0 rh_idx_rwhappy_0 rnumdis_rwhappy_4 sp_rnumdis_rwhappy_0* ///
   using /bbkinghome/noto/stateDependentUtility/rand/table9_alt_health.txt,  keep(ybar_iXhealth_it health_it ybar_iXshealth_it shealth_it ) ///
 stats(MU_inc MU_inc_se r2 N ind_N within_se onesd_b_over_muinc onesd_b_se , fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 

estout rnumdis_rwhappy_5 med_tot_rwhappy_0 hilo* ///
   using /bbkinghome/noto/stateDependentUtility/rand/table9_XX.txt.txt, keep(ybar_iXhealth_it health_it ) ///
 stats(MU_inc MU_inc_se r2 N ind_N within_se onesd_b_over_muinc onesd_b_se , fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 

** wealth_all ybarXwaveFE w0pct w10pct 
estout rnumdis_rwhappy_0 edyrs curr_inc wealth ybarXwave other_inters ///
   using /bbkinghome/noto/stateDependentUtility/rand/table10_other.txt,  keep(ybar_iXhealth_it health_it log_inc_curr) ///
 stats(MU_inc MU_inc_se r2 N ind_N within_se onesd_b_over_muinc onesd_b_se , fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 

**
** rnumdis_rwhappy_9   (50%)
** rnumdis_rwhappy_10  (75%)
** rnumdis_rwhappy_11  (90%)
** rnumdis_rwhappy_8 - drop homemakers
**  (rnumdis_rwhappy_7 rnumdis_rwhappy_13 rnumdis_rwhappy_12)
**
estout rnumdis_rwhappy_0  rnumdis_rwhappy_9 rnumdis_rwhappy_10 rnumdis_rwhappy_1 rnumdis_rwhappy_2 rnumdis_rwhappy_8 rnumdis_rwhappy_14 ///
   using /bbkinghome/noto/stateDependentUtility/rand/table13_alt_samps.txt, drop( _I* *age* *dummy* single hh_size *cons* ) ///
 stats(MU_inc MU_inc_se r2 N ind_N within_se  onesd_b_over_muinc onesd_b_se , fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 

exit








estout sample0_curr_noFE *curr_FE ///
   using /bbkinghome/noto/stateDependentUtility/rand/table8.txt, drop( _I* *age* *dummy* single hh_size *cons* ) ///
 stats(MU_inc r2 N ind_N within_se one_b_over_muinc one_b_se onesd_b_over_muinc onesd_b_se one_bs_over_muinc one_bs_se onesd_bs_over_muinc onesd_bs_se, fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 



exit

estout rnumdis_rcesd4_0 *l_tot_rcesd4_0 r_sh_rcesd4_0 rnd_wpsy_rcesd4_0 rnumdis6_rcesd4_0 med_tot_rcesd4_0 rh_idx_rcesd4_0 lng_db_st*_rcesd4_0  rnumdisw_rcesd4_0 sp_rnumdis_rcesd4_0 rnumdis_rcesd4_1 rnumdis_rcesd4_2 rnumdis_rcesd4_3 rnumdis_rcesd4_4 rnumdis_rcesd4_5 rnumdis_rcesd4_6 ///
   using /bbkinghome/noto/stateDependentUtility/rand/tableA1.txt, drop( _I* *age* *dummy* single hh_size) ///
 stats(MU_inc r2 N ind_N within_se one_b_over_muinc one_b_se onesd_b_over_muinc onesd_b_se one_bs_over_muinc one_bs_se onesd_bs_over_muinc onesd_bs_se, fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 

estout rnumdis_rcesd_0 *l_tot_rcesd_0 r_sh_rcesd_0 rnd_wpsy_rcesd_0 rnumdis6_rcesd_0 med_tot_rcesd_0 rh_idx_rcesd4_0 lng_db_st*_rcesd_0 rnumdisw_rcesd_0 sp_rnumdis_rcesd_0 rnumdis_rcesd_1 rnumdis_rcesd_2 rnumdis_rcesd_3 rnumdis_rcesd_4 rnumdis_rcesd_5 rnumdis_rcesd_6 ///
   using /bbkinghome/noto/stateDependentUtility/rand/tableA2.txt, drop( _I* *age* *dummy* single hh_size) ///
 stats(MU_inc r2 N ind_N within_se one_b_over_muinc one_b_se onesd_b_over_muinc onesd_b_se one_bs_over_muinc one_bs_se onesd_bs_over_muinc onesd_bs_se, fmt(%9.3f)) modelwidth(15) ///
 cells(b( fmt(%9.3f)) se(par fmt(%9.3f)) p(par([ ]) fmt(%9.3f)) ) style(tab) replace notype mlabels(, numbers ) 
