
set more off

est clear
drop _all
use /tmp/bsample_`1'.dta

/*
summ hhidpn
local max_hhidpn = r(max)
sort hhidpn wave
by hhidpn wave: replace hhidpn = (`max_hhidpn' + 1) * (_n - 1) + hhidpn 
 */

keep if sample0 == 1

local BIN_HAPPY  = `2'
local BIN_NUMDIS = `3'

bys hhidpn: egen mean_happy  = mean(rwhappy)
bys hhidpn: egen mean_numdis = mean(rnumdis)

drop if mean_happy == 0
drop if mean_happy == 1

replace log_inc_perm = log(inc_perm / 1000)
summ log_inc_perm
replace log_inc_perm = log_inc_perm - r(mean)
capture drop ybar_iXhealth_it
gen double ybar_iXhealth_it   = log_inc_perm * rnumdis

local NUM_BINS_HAPPY = 1/`BIN_HAPPY'
local NUM_BINS_NUMDIS = 7/`BIN_NUMDIS'

matrix results = J(200, 4, .)
local num_inds = 0
local r = 1

forvalues i = 1/`NUM_BINS_HAPPY' {
 forvalues j = 1/`NUM_BINS_NUMDIS' {
 
 local lower_happy = (`i'-1)*`BIN_HAPPY' 
 local upper_happy = (`i'  )*`BIN_HAPPY' 

 local lower_numdis = (`j'-1)*`BIN_NUMDIS'
 local upper_numdis = (`j'  )*`BIN_NUMDIS'

 capture drop myn
 sort hhidpn wave
 by hhidpn: gen myn = _n

 qui count if mean_happy >= `lower_happy' & mean_happy <  `upper_happy' & ///
          mean_numdis >= `lower_numdis' & mean_numdis < `upper_numdis' & myn == 1
 local N = r(N)

 if (`N' > 1) {

  local num_inds = `N' + `num_inds'

  **summ log_inc_perm if mean_happy >= `lower_happy' & mean_happy <  `upper_happy' & ///
                       mean_numdis >= `lower_numdis' & mean_numdis < `upper_numdis'

  qui reg rwhappy rnumdis log_inc_perm ybar_iXhealth_it ///
       if mean_happy >= `lower_happy' & mean_happy <  `upper_happy' & ///
          mean_numdis >= `lower_numdis' & mean_numdis < `upper_numdis', 

   qui test ybar_iXhealth_it
   local p1 = r(p)
   qui test rnumdis
   local p2 = r(p)

   *if (`p1' < .) {

   matrix results[`r', 1] = _b[ybar_iXhealth_it]
   matrix results[`r', 2] = 1-ttail(e(df_r), _b[ybar_iXhealth_it]/_se[ybar_iXhealth_it])
   matrix results[`r', 3] = _b[rnumdis]
   matrix results[`r', 4] = 1-ttail(e(df_r), _b[rnumdis]/_se[rnumdis])
   local r = `r' + 1

   *}

 }

}
}



 qui {

matrix list results

svmat results
summ results*
summ results2
local mean2 = r(mean)
summ results4
local mean4 = r(mean)
count if results1 < .
local N = r(N)
count if results1 < 0
local frac1 = r(N) / `N'
di "frac: `frac1' ..."
count if results3 < 0
local frac3 = r(N) / `N'
di "frac: `frac3' ..."
di "num_inds: `num_inds' ..."

local num_cells = 7/(`BIN_HAPPY'*`BIN_NUMDIS')
local avg = `num_inds' / `N'

reg results2
test _cons == 0.5
local pval2 = r(p)
reg results4
test _cons == 0.5
local pval4 = r(p)

 }




**
* The forvalues cleans up formatting...
**
forvalues i = 1/1 {

 capture log close
 log using ${OUTPUT_DIRECTORY}/table4_c`4'_`2'_`3'.txt, replace text

 di " "
 di "TABLE 4: NONPARAMETRIC TESTS"
 di " "
 di "Bin width for mean happiness: `BIN_HAPPY'"
 di "Bin width for mean number of diseases: `BIN_NUMDIS'"
 di "Number of cells: `num_cells'"
 di "Number of usable cells: `N'"
 di "Number of individuals in usable cells: `num_inds'"
 di "Average number of individuals per used cell: `avg'"
 di " "
 di "Mean of CDFs of t-statistics: `mean2'"
 di "p-value: `pval2'"
 di "Fraction of estimated interaction terms < 0: `frac1'"
 di " "
 di "Mean of CDFs of t-statistics: `mean4'"
 di "p-value: `pval4'"
 di "Fraction of estimated direct terms < 0: `frac3'"
 di " "

 log close

}


exit
